==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebFilteringOperationDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFilteringOperationDescription } from "./WebFilteringOperationDescription";
/**
 * @hidden
 */
export let WebFilteringOperationDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebFilteringOperationDescriptionMetadata extends Base {
        static b(a) {
            if (WebFilteringOperationDescriptionMetadata.a == null) {
                WebFilteringOperationDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebFilteringOperationDescriptionMetadata.c(WebFilteringOperationDescriptionMetadata.a);
            }
            if (a.k(WebFilteringOperationDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebFilteringOperationDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:FilteringOperation");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("__isTSPlainInterface", "Boolean");
            a.item("Name", "String");
            a.item("IsUnary", "Boolean");
            a.item("IconName", "String");
            a.item("Hidden", "Boolean");
            a.item("LogicRef", "(w:Logic,wf:Logic)MethodRef");
        }
        static d(a) {
            WebFilteringOperationDescriptionMetadata.b(a);
            a.ad("WebFilteringOperation", () => new WebFilteringOperationDescription());
            a.ac("WebFilteringOperation", WebFilteringOperationDescriptionMetadata.a);
        }
    }
    WebFilteringOperationDescriptionMetadata.$t = markType(WebFilteringOperationDescriptionMetadata, 'WebFilteringOperationDescriptionMetadata');
    WebFilteringOperationDescriptionMetadata.a = null;
    return WebFilteringOperationDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebFilteringOperationDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFilteringOperationDescription } from "./WebFilteringOperationDescription";
/**
 * @hidden
 */
export let WebFilteringOperationDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebFilteringOperationDescriptionMetadata extends Base {
        static b(a) {
            if (WebFilteringOperationDescriptionMetadata.a == null) {
                WebFilteringOperationDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebFilteringOperationDescriptionMetadata.c(WebFilteringOperationDescriptionMetadata.a);
            }
            if (a.k(WebFilteringOperationDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebFilteringOperationDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:FilteringOperation");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("__isTSPlainInterface", "Boolean");
            a.item("Name", "String");
            a.item("IsUnary", "Boolean");
            a.item("IsNestedQuery", "Boolean");
            a.item("IconName", "String");
            a.item("Hidden", "Boolean");
            a.item("LogicRef", "(w:Logic,wf:Logic)MethodRef");
        }
        static d(a) {
            WebFilteringOperationDescriptionMetadata.b(a);
            a.ae("WebFilteringOperation", () => new WebFilteringOperationDescription());
            a.ad("WebFilteringOperation", WebFilteringOperationDescriptionMetadata.a);
        }
    }
    WebFilteringOperationDescriptionMetadata.$t = markType(WebFilteringOperationDescriptionMetadata, 'WebFilteringOperationDescriptionMetadata');
    WebFilteringOperationDescriptionMetadata.a = null;
    return WebFilteringOperationDescriptionMetadata;
})();
